/* Pong - A version of Pong based on Ncurses
 * Copyright (C) 1999 Jeffrey Wade Starr <starr81@ix.netcom.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */   

// ball.hpp
// Specification for the ball in pong (ver 0.2)
// By Jeffrey W. Starr Oct 14 1998

#ifndef BALL_H
#define BALL_H

class Ball
{
public:
  Ball(int xc, int yc, int dir);        // constructor
  int distEdge();                       // returns distance to edge (x)
  int distTop();                        // returns distance from the top (y)
  int direction();                      // returns the direction it's going
  void bounce(int newdirect);           // change direction to 1,2,3
  void moveball();                      // from event - move the ball
  
private:
  void showBall();

  int x, y;
  int direct;
};

Ball::Ball(int xc, int yc, int dir)
{
  y = yc;
  x = xc;
  direct = dir;
}

inline int Ball::distEdge()
{
  return x;
}

inline int Ball::distTop()
{
  return y;
}

inline int Ball::direction()
{
  return direct;
}

void Ball::moveball()
{
  switch(direct)
    {
    case 1:   y++; x--; showBall(); break;
    case 2:   y++; showBall(); break;
    case 3:   y++; x++; showBall(); break;
    case 4:   x--; showBall(); break;
    case 5:   mvaddch(2,2,'!'); break; // should never happen
    case 6:   x++; showBall(); break;
    case 7:   y--; x--; showBall(); break;
    case 8:   y--; showBall(); break;
    case 9:   y--; x++; showBall(); break;
    default:  break;
    }
}

void Ball::showBall()
{
  // clear last image of ball
  switch(direct)
    {
    case 1:  mvaddch(y-1, x+1, ' '); break;
    case 2:  mvaddch(y-1, x, ' ');   break;
    case 3:  mvaddch(y-1, x-1, ' '); break;
    case 4:  mvaddch(y, x+1, ' ');   break;
    case 5:  mvaddch(2,2,'?');       break;
    case 6:  mvaddch(y, x-1, ' ');   break;
    case 7:  mvaddch(y+1, x+1, ' '); break;
    case 8:  mvaddch(y+1, x, ' ');   break;
    case 9:  mvaddch(y+1, x-1, ' '); break;
    default: break;
    }

  // put down image of ball
  mvaddch(y, x, 'O');
  
  refresh();
}

inline void Ball::bounce(int newdirect)
{
  direct = newdirect;
}

#endif

